=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-04-15 01:30:58 +0000
+++ CMakeLists.txt	2013-04-16 02:37:02 +0000
@@ -47,6 +47,23 @@
 add_custom_target(cppcheck COMMAND cppcheck --enable=all -q --error-exitcode=2
                                        ${CMAKE_SOURCE_DIR}/src ${CMAKE_SOURCE_DIR}/tests)
 
+#
+# Definitions for testing with valgrind.
+#
+
+configure_file(CTestCustom.cmake.in CTestCustom.cmake) # Tests in CTestCustom.cmake are skipped for valgrind
+
+find_program(MEMORYCHECK_COMMAND NAMES valgrind)
+if (MEMORYCHECK_COMMAND)
+    set(MEMORYCHECK_COMMAND_OPTIONS
+        "--suppressions=${CMAKE_SOURCE_DIR}/valgrind-suppress --leak-check=full --num-callers=40 --error-exitcode=3"
+    )
+    add_custom_target(valgrind DEPENDS NightlyMemCheck)
+else()
+    message(WARNING "Cannot find valgrind: valgrind target will not be available")
+endif()
+
+
 include(FindPkgConfig)
 find_package(Qt5Qml)
 find_package(Qt5Quick)
@@ -108,6 +125,7 @@
 set(LIBS ${UNITY_API_LIB} ${OTHER_API_LIBS})
 
 # Tests
+include(CTest)
 enable_testing()
 add_custom_target(check make test CTEST_OUTPUT_ON_FAILURE=1)
 

=== added file 'CTestCustom.cmake.in'
--- CTestCustom.cmake.in	1970-01-01 00:00:00 +0000
+++ CTestCustom.cmake.in	2013-04-16 02:37:02 +0000
@@ -0,0 +1,16 @@
+#
+# Tests listed here will not be run by the valgrind target.
+#
+
+SET(CTEST_CUSTOM_MEMCHECK_IGNORE
+    cleanincludes
+    testAnimationControllerWithSignals
+    testCarousel
+    testClock
+    testCrossFadeImage
+    testIndicatorItem
+    testMathLocal
+    testRatingStars
+    testSideStage
+    testTimeLocal
+    whitespace)

=== modified file 'debian/control'
--- debian/control	2013-04-15 10:36:03 +0000
+++ debian/control	2013-04-16 02:37:02 +0000
@@ -27,6 +27,7 @@
                libgtest-dev,
                libc6-dev,
                python3,
+               valgrind,
 Standards-Version: 3.9.3
 Vcs-Bzr: lp:unity/phablet
 

=== added file 'valgrind-suppress'
--- valgrind-suppress	1970-01-01 00:00:00 +0000
+++ valgrind-suppress	2013-04-16 02:37:02 +0000
@@ -0,0 +1,13 @@
+{
+    g_main_leak
+    Memcheck:Leak
+    fun:memalign
+    fun:posix_memalign
+    obj:/lib/x86_64-linux-gnu/libglib-2.0.so.0.3600.0
+    fun:g_slice_alloc
+    fun:g_slice_alloc0
+    fun:g_thread_self
+    fun:g_main_context_acquire
+    fun:g_main_context_push_thread_default
+    ...
+}

